==> waitress-0.8.tar.gz: waitress-0.8/waitress/tests/fixtureapps/filewrapper.py <==
import os

here = os.path.dirname(os.path.abspath(__file__))
fn = os.path.join(here, 'groundhog1.jpg')

class KindaFilelike(object):
    def __init__(self, bytes):
        self.bytes = bytes

    def read(self, n):
        bytes = self.bytes[:n]
        self.bytes = self.bytes[n:]
        return bytes

def app(environ, start_response):
    path_info = environ['PATH_INFO']
    if path_info.startswith('/filelike'):
        f = open(fn, 'rb')
        f.seek(0, 2)
        cl = f.tell()
        f.seek(0)
        if path_info == '/filelike':
            headers = [
                ('Content-Length', str(cl)), ('Content-Type', 'image/jpeg')
                ]
        elif path_info == '/filelike_nocl':
            headers = [('Content-Type', 'image/jpeg')]
        elif path_info == '/filelike_shortcl':
            # short content length
            headers = [
                ('Content-Length', '1'), ('Content-Type', 'image/jpeg')
                ]
        else:
            # long content length (/filelike_longcl)
            headers = [
                ('Content-Length', str(cl+10)), ('Content-Type', 'image/jpeg')
                ]
    else:
        data = open(fn, 'rb').read()
        cl = len(data)
        f = KindaFilelike(data)
        if path_info == '/notfilelike':
            headers =  [('Content-Length', str(len(data))),
                        ('Content-Type', 'image/jpeg')]
            
        elif path_info == '/notfilelike_nocl':
            headers = [('Content-Type', 'image/jpeg')]
        elif path_info == '/notfilelike_shortcl':
            # short content length
            headers = [
                ('Content-Length', '1'), ('Content-Type', 'image/jpeg')
                ]
        else:
            # long content length (/notfilelike_longcl)
            headers = [
                ('Content-Length', str(cl+10)), ('Content-Type', 'image/jpeg')
                ]

    start_response(
        '200 OK',
        headers
        )
    return environ['wsgi.file_wrapper'](f, 8192)

if __name__ == '__main__':
    import logging
    class NullHandler(logging.Handler):
        def emit(self, record):
            pass
    h = NullHandler()
    logging.getLogger('waitress').addHandler(h)
    from waitress import serve
    serve(app, port=61523, _quiet=True)

==> waitress-0.8.4.tar.gz: waitress-0.8.4/waitress/tests/fixtureapps/filewrapper.py <==
import os

here = os.path.dirname(os.path.abspath(__file__))
fn = os.path.join(here, 'groundhog1.jpg')

class KindaFilelike(object):

    def __init__(self, bytes):
        self.bytes = bytes

    def read(self, n):
        bytes = self.bytes[:n]
        self.bytes = self.bytes[n:]
        return bytes

def app(environ, start_response):
    path_info = environ['PATH_INFO']
    if path_info.startswith('/filelike'):
        f = open(fn, 'rb')
        f.seek(0, 2)
        cl = f.tell()
        f.seek(0)
        if path_info == '/filelike':
            headers = [
                ('Content-Length', str(cl)),
                ('Content-Type', 'image/jpeg'),
            ]
        elif path_info == '/filelike_nocl':
            headers = [('Content-Type', 'image/jpeg')]
        elif path_info == '/filelike_shortcl':
            # short content length
            headers = [
                ('Content-Length', '1'),
                ('Content-Type', 'image/jpeg'),
            ]
        else:
            # long content length (/filelike_longcl)
            headers = [
                ('Content-Length', str(cl + 10)),
                ('Content-Type', 'image/jpeg'),
            ]
    else:
        data = open(fn, 'rb').read()
        cl = len(data)
        f = KindaFilelike(data)
        if path_info == '/notfilelike':
            headers = [
                ('Content-Length', str(len(data))),
                ('Content-Type', 'image/jpeg'),
            ]
        elif path_info == '/notfilelike_nocl':
            headers = [('Content-Type', 'image/jpeg')]
        elif path_info == '/notfilelike_shortcl':
            # short content length
            headers = [
                ('Content-Length', '1'),
                ('Content-Type', 'image/jpeg'),
            ]
        else:
            # long content length (/notfilelike_longcl)
            headers = [
                ('Content-Length', str(cl + 10)),
                ('Content-Type', 'image/jpeg'),
            ]

    start_response(
        '200 OK',
        headers
    )
    return environ['wsgi.file_wrapper'](f, 8192)

if __name__ == '__main__':
    from waitress.tests.support import start_server
    start_server(app)
